PaytmPaymentsCustomuisdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • PaytmPaymentsCustomuisdkPlatform
Implementers

Constructors

PaytmPaymentsCustomuisdkPlatform()
Constructs a PaytmPaymentsCustomuisdkPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchEmiDetails(String channelCode, String cardType) Future<Map>
fetchNBList(String tokenType, String token, String mid, [String? orderId, String? referenceId]) Future<Map?>
getBin(String cardSixDigit, String tokenType, String token, String mid, [String? referenceId]) Future<Map>
getEnvironment() Future<String>
getLastNBSavedBank() Future
getLastSavedVPA() Future
getUpiIntentList() Future<Map>
getUpiIntentSubscriptionList() Future<Map>
goForNetBankingTransaction(String netBankingCode, String paymentFlow) Future<Map>
goForNewCardTransaction(String cardNumber, String cardExpiry, String cardCvv, String cardType, String paymentFlow, String channelCode, String issuingBankCode, String? emiChannelId, String authMode, bool saveCard) Future<Map>
goForSavedCardTransaction(String cardId, String cardCvv, String cardType, String paymentFlow, String channelCode, String issuingBankCode, String? emiChannelId, String? authMode) Future<Map>
goForUpiCollectTransaction(String upiCode, String paymentFlow, bool saveVPA) Future<Map>
goForUpiIntentSubscriptionTransaction(String appName, String paymentFlow) Future<Map>
goForUpiIntentTransaction(String appName, String paymentFlow) Future<Map>
goForWalletTransaction(String paymentFlow) Future<Map>
initPaytmSDK(String mid, String orderId, String txnToken, String amount, bool isStaging, String callbackUrl) → void
invokePaytmAppOrRedirect() Future<Map>
isPaytmAppInstalled() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEnvironment(String environment) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance PaytmPaymentsCustomuisdkPlatform
The default instance of PaytmPaymentsCustomuisdkPlatform to use.
getter/setter pair