MethodChannelPaytmPaymentsCustomuisdk class
An implementation of PaytmPaymentsCustomuisdkPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- PaytmPaymentsCustomuisdkPlatform
- MethodChannelPaytmPaymentsCustomuisdk
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchEmiDetails(
String channelCode, String cardType) → Future< Map> -
override
-
fetchNBList(
String tokenType, String token, String mid, [String? orderId, String? referenceId]) → Future< Map?> -
override
-
getBin(
String cardSixDigit, String tokenType, String token, String mid, [String? referenceId]) → Future< Map> -
override
-
getEnvironment(
) → Future< String> -
override
-
getLastNBSavedBank(
) → Future -
override
-
getLastSavedVPA(
) → Future -
override
-
getUpiIntentList(
) → Future< Map> -
override
-
getUpiIntentSubscriptionList(
) → Future< Map> -
override
-
goForNetBankingTransaction(
String netBankingCode, String paymentFlow) → Future< Map> -
override
-
goForNewCardTransaction(
String cardNumber, String cardExpiry, String cardCvv, String cardType, String paymentFlow, String channelCode, String issuingBankCode, String? emiChannelId, String authMode, bool saveCard) → Future< Map> -
override
-
goForSavedCardTransaction(
String cardId, String cardCvv, String cardType, String paymentFlow, String channelCode, String issuingBankCode, String? emiChannelId, String? authMode) → Future< Map> -
override
-
goForUpiCollectTransaction(
String upiCode, String paymentFlow, bool saveVPA) → Future< Map> -
override
-
goForUpiIntentSubscriptionTransaction(
String appName, String paymentFlow) → Future< Map> -
override
-
goForUpiIntentTransaction(
String appName, String paymentFlow) → Future< Map> -
override
-
goForWalletTransaction(
String paymentFlow) → Future< Map> -
override
-
initPaytmSDK(
String mid, String orderId, String txnToken, String amount, bool isStaging, String callbackUrl) → void -
override
-
invokePaytmAppOrRedirect(
) → Future< Map> -
override
-
isPaytmAppInstalled(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setEnvironment(
String environment) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited